@@ -8,100 +8,144 @@
 #  The original version was written in Objective-C by Malcolm Crawford
 #  http://homepage.mac.com/mmalc/CocoaExamples/controllers.html
 
+
+import objc
+from Circle import Circle
+from Cocoa import (
+    NSBezierPath,
+    NSColor,
+    NSDrawLightBezel,
+    NSIndexSet,
+    NSInsetRect,
+    NSIntersectsRect,
+    NSKeyValueChangeNewKey,
+    NSKeyValueChangeOldKey,
+    NSKeyValueObservingOptionNew,
+    NSKeyValueObservingOptionOld,
+    NSMakeRect,
+    NSNotFound,
+    NSShiftKeyMask,
+    NSUnionRect,
+    NSView,
+)
+from objc import super
+
+
 PropertyObservationContext = 1091
 GraphicsObservationContext = 1092
 SelectionIndexesObservationContext = 1093
 
 
-from Foundation import *
-from AppKit import *
-from objc import ivar
-from Circle import Circle
-from sets import Set
-
 class GraphicsView(NSView):
-    graphicsContainer = ivar(u'graphicsContainer')
-    graphicsKeyPath   = ivar(u'graphicsKeyPath')
+    graphicsContainer = objc.ivar("graphicsContainer")
+    graphicsKeyPath = objc.ivar("graphicsKeyPath")
 
-    selectionIndexesContainer = ivar(u'selectionIndexesContainer') # GraphicsArrayController
-    selectionIndexesKeyPath   = ivar(u'selectionIndexesKeyPath')
+    selectionIndexesContainer = objc.ivar(
+        "selectionIndexesContainer"
+    )  # GraphicsArrayController
+    selectionIndexesKeyPath = objc.ivar("selectionIndexesKeyPath")
 
-    oldGraphics = ivar(u'oldGraphics')
+    oldGraphics = objc.ivar("oldGraphics")
 
     def exposedBindings(self):
-        return [u"graphics", u"selectedObjects"]
+        return ["graphics", "selectedObjects"]
 
     def initWithFrame_(self, frameRect):
-        return super(GraphicsView, self).initWithFrame_(frameRect)
+        return super().initWithFrame_(frameRect)
 
     def graphics(self):
-        if not self.graphicsContainer: return None
+        if not self.graphicsContainer:
+            return None
         return self.graphicsContainer.valueForKeyPath_(self.graphicsKeyPath)
 
     def selectionIndexes(self):
-        if not self.selectionIndexesContainer: return None
-        return self.selectionIndexesContainer.valueForKeyPath_(self.selectionIndexesKeyPath)
+        if not self.selectionIndexesContainer:
+            return None
+        return self.selectionIndexesContainer.valueForKeyPath_(
+            self.selectionIndexesKeyPath
+        )
 
     def startObservingGraphics_(self, graphics):
-        if not graphics: return
+        if not graphics:
+            return
         # Register to observe each of the new graphics, and
         # each of their observable properties -- we need old and new
         # values for drawingBounds to figure out what our dirty rect
         for newGraphic in graphics:
             # Register as observer for all the drawing-related properties
             newGraphic.addObserver_forKeyPath_options_context_(
-                self, u"drawingBounds", (NSKeyValueObservingOptionNew | NSKeyValueObservingOptionOld),
-                PropertyObservationContext)
+                self,
+                "drawingBounds",
+                (NSKeyValueObservingOptionNew | NSKeyValueObservingOptionOld),
+                PropertyObservationContext,
+            )
             keys = Circle.keysForNonBoundsProperties()
             for key in keys:
                 newGraphic.addObserver_forKeyPath_options_context_(
-                    self, key, 0, PropertyObservationContext)
+                    self, key, 0, PropertyObservationContext
+                )
 
     def stopObservingGraphics_(self, graphics):
-        if graphics is None: return
+        if graphics is None:
+            return
         for graphic in graphics:
             for key in graphic.class__().keysForNonBoundsProperties():
                 graphic.removeObserver_forKeyPath_(self, key)
-            graphic.removeObserver_forKeyPath_(self, u"drawingBounds")
+            graphic.removeObserver_forKeyPath_(self, "drawingBounds")
 
-    def bind_toObject_withKeyPath_options_(self, bindingName, observableObject, observableKeyPath, options):
-        if bindingName == u"graphics":
+    def bind_toObject_withKeyPath_options_(
+        self, bindingName, observableObject, observableKeyPath, options
+    ):
+        if bindingName == "graphics":
             self.graphicsContainer = observableObject
             self.graphicsKeyPath = observableKeyPath
             self.graphicsContainer.addObserver_forKeyPath_options_context_(
-                    self, self.graphicsKeyPath, (NSKeyValueObservingOptionNew |
-                    NSKeyValueObservingOptionOld), GraphicsObservationContext)
+                self,
+                self.graphicsKeyPath,
+                (NSKeyValueObservingOptionNew | NSKeyValueObservingOptionOld),
+                GraphicsObservationContext,
+            )
             self.startObservingGraphics_(self.graphics())
 
-        elif bindingName == u"selectionIndexes":
+        elif bindingName == "selectionIndexes":
             self.selectionIndexesContainer = observableObject
             self.selectionIndexesKeyPath = observableKeyPath
             self.selectionIndexesContainer.addObserver_forKeyPath_options_context_(
-                self, self.selectionIndexesKeyPath, 0, SelectionIndexesObservationContext)
+                self,
+                self.selectionIndexesKeyPath,
+                0,
+                SelectionIndexesObservationContext,
+            )
         self.setNeedsDisplay_(True)
 
     def unbind_(self, bindingName):
-        if bindingName == u"graphics":
-            self.graphicsContainer.removeObserver_forKeyPath_(self, self.graphicsKeyPath)
+        if bindingName == "graphics":
+            self.graphicsContainer.removeObserver_forKeyPath_(
+                self, self.graphicsKeyPath
+            )
             self.graphicsContainer = None
             self.graphicsKeyPath = None
-        if bindingName == u"selectionIndexes":
-            self.selectionIndexesContainer.removeObserver_forKeyPath_(self, self.selectionIndexesKeyPath)
+        if bindingName == "selectionIndexes":
+            self.selectionIndexesContainer.removeObserver_forKeyPath_(
+                self, self.selectionIndexesKeyPath
+            )
             self.seletionIndexesContainer = None
             self.selectionIndexesKeyPath = None
         self.setNeedsDisplay_(True)
 
-    def observeValueForKeyPath_ofObject_change_context_(self, keyPath, object, change, context):
+    def observeValueForKeyPath_ofObject_change_context_(
+        self, keyPath, an_object, change, context
+    ):
         if context == GraphicsObservationContext:
             # Should be able to use
             # NSArray *oldGraphics = [change objectForKey:NSKeyValueChangeOldKey];
             # etc. but the dictionary doesn't contain old and new arrays...??
-            newGraphics = Set(object.valueForKeyPath_(self.graphicsKeyPath))
-            onlyNew = newGraphics - Set(self.oldGraphics)
+            newGraphics = set(an_object.valueForKeyPath_(self.graphicsKeyPath))
+            onlyNew = newGraphics - set(self.oldGraphics or [])
             self.startObservingGraphics_(onlyNew)
 
             if self.oldGraphics:
-                removed = Set(self.oldGraphics) - newGraphics
+                removed = set(self.oldGraphics) - newGraphics
                 self.stopObservingGraphics_(removed)
 
             self.oldGraphics = newGraphics
@@ -114,16 +158,18 @@ class GraphicsView(NSView):
             updateRect = (0,)
             # Note: for Circle, drawingBounds is a dependent key of all the other
             # property keys except color, so we'll get this anyway...
-            if keyPath == u"drawingBounds":
+            if keyPath == "drawingBounds":
                 newBounds = change.objectForKey_(NSKeyValueChangeNewKey)
                 oldBounds = change.objectForKey_(NSKeyValueChangeOldKey)
                 updateRect = NSUnionRect(newBounds, oldBounds)
             else:
-                updateRect = object.drawingBounds()
-            updateRect = NSMakeRect(updateRect.origin.x-1.0,
-                                updateRect.origin.y-1.0,
-                                updateRect.size.width+2.0,
-                                updateRect.size.height+2.0)
+                updateRect = an_object.drawingBounds()
+            updateRect = NSMakeRect(
+                updateRect.origin.x - 1.0,
+                updateRect.origin.y - 1.0,
+                updateRect.size.width + 2.0,
+                updateRect.size.height + 2.0,
+            )
             self.setNeedsDisplay_(True)
             return
 
@@ -133,7 +179,7 @@ class GraphicsView(NSView):
 
     def drawRect_(self, rect):
         myBounds = self.bounds()
-        NSDrawLightBezel(myBounds, myBounds) # AppKit Function
+        NSDrawLightBezel(myBounds, myBounds)  # AppKit Function
         clipRect = NSBezierPath.bezierPathWithRect_(NSInsetRect(myBounds, 2.0, 2.0))
         clipRect.addClip()
 
@@ -149,8 +195,8 @@ class GraphicsView(NSView):
         # Selection should be handled by the graphic, but this is a
         # shortcut simply for display.
 
-        currentSelectionIndexes = self.selectionIndexes() # ist das wir ein Array im Indezes?
-        if currentSelectionIndexes != None:
+        currentSelectionIndexes = self.selectionIndexes()
+        if currentSelectionIndexes is not None:
             path = NSBezierPath.bezierPath()
             index = currentSelectionIndexes.firstIndex()
             while index != NSNotFound:
@@ -163,22 +209,25 @@ class GraphicsView(NSView):
             path.setLineWidth_(1.5)
             path.stroke()
 
-
         # Fairly simple just to illustrate the point
+
     def mouseDown_(self, event):
         # find out if we hit anything
         p = self.convertPoint_fromView_(event.locationInWindow(), None)
         for aGraphic in self.graphics():
             if aGraphic.hitTest_isSelected_(p, False):
-                break; # aGraphic soll spaeter einen Wert haben, falls es getroffene gibt!
+                break
+
         else:
             aGraphic = None
 
         # if no graphic hit, then if extending selection do nothing
         # else set selection to nil
-        if aGraphic == None:
+        if aGraphic is None:
             if not event.modifierFlags() & NSShiftKeyMask:
-                self.selectionIndexesContainer.setValue_forKeyPath_(None, self.selectionIndexesKeyPath)
+                self.selectionIndexesContainer.setValue_forKeyPath_(
+                    None, self.selectionIndexesKeyPath
+                )
             return
 
         # graphic hit
@@ -191,14 +240,17 @@ class GraphicsView(NSView):
         if not event.modifierFlags() & NSShiftKeyMask:
             selection = NSIndexSet.indexSetWithIndex_(graphicIndex)
         else:
-            if  self.selectionIndexes().containsIndex_(graphicIndex):
+            if self.selectionIndexes().containsIndex_(graphicIndex):
                 selection = self.selectionIndexes().mutableCopy()
                 selection.removeIndex_(graphicIndex)
             else:
                 selection = self.selectionIndexes().mutableCopy()
                 selection.addIndex_(graphicIndex)
-        self.selectionIndexesContainer.setValue_forKeyPath_(selection, self.selectionIndexesKeyPath)
+
+        self.selectionIndexesContainer.setValue_forKeyPath_(
+            selection, self.selectionIndexesKeyPath
+        )
 
 
-GraphicsView.exposeBinding_(u"graphics")
-GraphicsView.exposeBinding_(u"selectionIndexes")
+GraphicsView.exposeBinding_("graphics")
+GraphicsView.exposeBinding_("selectionIndexes")
