@@ -1,13 +1,21 @@
 import array
 import sys
 
-import objc
 import AppKit
 from objc import NO, YES
 from PyObjCTools.TestSupport import TestCase, min_os_level
 
 
 class TestNSBitmapImageRep(TestCase):
+    def test_typed_enum(self):
+        self.assertIsTypedEnum(AppKit.NSBitmapImageRepPropertyKey, str)
+
+    def test_enum_types(self):
+        self.assertIsEnumType(AppKit.NSBitmapFormat)
+        self.assertIsEnumType(AppKit.NSBitmapImageFileType)
+        self.assertIsEnumType(AppKit.NSImageRepLoadStatus)
+        self.assertIsEnumType(AppKit.NSTIFFCompression)
+
     def testInstantiation(self):
         # widthxheight RGB 24bpp image
         width = 256
@@ -43,7 +51,7 @@ class TestNSBitmapImageRep(TestCase):
         )
         self.assertIsInstance(i1, AppKit.NSBitmapImageRep)
 
-        singlePlane = objc.allocateBuffer(width * height * 4)
+        singlePlane = bytearray(width * height * 4)
         for i in range(0, width * height):
             si = i * 4
             singlePlane[si] = 1
@@ -101,7 +109,7 @@ class TestNSBitmapImageRep(TestCase):
         )
         self.assertTrue(i1)
 
-        singlePlane = objc.allocateBuffer(width * height * 3)
+        singlePlane = bytearray(width * height * 3)
         for i in range(0, width * height):
             si = i * 3
             if sys.version_info[0] == 2:
