@@ -29,6 +29,7 @@ class TestNSBundle(TestCase):
         self.assertEqual(AppKit.NSBundleExecutableArchitecturePPC, 0x00000012)
         self.assertEqual(AppKit.NSBundleExecutableArchitectureX86_64, 0x01000007)
         self.assertEqual(AppKit.NSBundleExecutableArchitecturePPC64, 0x01000012)
+        self.assertEqual(AppKit.NSBundleExecutableArchitectureARM64, 0x0100000C)
 
         self.assertIsInstance(AppKit.NSBundleDidLoadNotification, str)
         self.assertIsInstance(AppKit.NSLoadedClasses, str)
@@ -38,3 +39,10 @@ class TestNSBundle(TestCase):
         self.assertHasAttr(Foundation, "NSLocalizedStringFromTable")
         self.assertHasAttr(Foundation, "NSLocalizedStringFromTableInBundle")
         self.assertHasAttr(Foundation, "NSLocalizedStringWithDefaultValue")
+
+    def testDefines12_0(self):
+        # XXX: these should only be available on macOS 12
+        self.assertHasAttr(Foundation, "NSLocalizedAttributedString")
+        self.assertHasAttr(Foundation, "NSLocalizedAttributedStringFromTable")
+        self.assertHasAttr(Foundation, "NSLocalizedAttributedStringFromTableInBundle")
+        self.assertHasAttr(Foundation, "NSLocalizedAttributedStringWithDefaultValue")
